@@ -1,11 +1,9 @@
 from .source_file.client import Client as files
 from .destination_sftp_json.client import SftpClient
 from .destination_azblob.destination import DestinationAzBlob
-from .source_postgres.client import PostgresSource
 
 __all__ = [
     'files',
     'SftpClient',
     'DestinationAzBlob',
-    'PostgresSource'
 ]
